==> alibabacloud_ros20190910_py2-2.2.2.tar.gz: alibabacloud_ros20190910_py2-2.2.2/ChangeLog.md <==
2022-02-28 Version: 2.2.1
- The response of GetServiceProvisions adds DependentServiceNames.

2022-02-22 Version: 2.2.0
- The parameter of GetStack, GetTemplate, ListTemplates, ListTemplateVersions adds AcceptLanguage.
- The response of GetStack, GetTemplate adds Interface.
- The parameter of CreateStack, CreateChangeSet adds ServiceManaged.
- The response of GetStack adds ServiceManaged, ServiceName.
- The response of ListStacks adds ServiceManaged, ServiceName in Stacks.

2022-01-18 Version: 2.1.0
- Added EntityType to ListResourceTypes parameters.
- Added EntityType to GetResourceType return value.

2022-01-12 Version: 2.0.6
- GetFeatureDetails return value adds UpdateAllowedTransforms.

2022-01-05 Version: 2.0.5
- GetTemplate return value adds TemplateId, TemplateVersion, TemplateScratchId and TemplateURL.

2021-12-20 Version: 2.0.4
- CreateStack, PreviewStack and GetTemplateEstimateCost parameters supports specifing TemplateScratchRegionId.
- GetTemplateScratch return value adds StackProvision and UsageType in Stacks.
- GetTemplate return value adds ShareSource in Permissions.

2021-12-14 Version: 2.0.3
- Fix the issue that some parameters cannot be passed.

2021-12-07 Version: 2.0.2
- API GetStack supports Log for Terraform Stack.
- API GetChangeSet supports Log for Terraform Stack.
- API PreviewStack supports Log for Terraform Stack.

2021-11-30 Version: 2.0.1
- API GetStack supports Log for Terraform Stack.
- API GetChangeSet supports Log for Terraform Stack.
- API PreviewStack supports Log for Terraform Stack.

2021-11-22 Version: 2.0.0
- Add API GetServiceProvisions.
- Add API GetTemplateParameterConstraints.
- Add API GetFeatureDetails.
- CreateChangeSet supports Parallelism.

2021-09-27 Version: 1.1.2
- Terraform stack supports custom of parallelism.

2021-09-03 Version: 1.1.1
- Fix type error of StackGroup and StackInstance parameters.

2021-09-03 Version: 1.1.0
- StackGroup supports specify resource folder to deploy StackInstances.
- StackGroup supports SERVICE_MANAGED and SELF_MANAGED permission models.

2021-08-27 Version: 1.0.1
- Support ClientToken for ValidateTemplate.

2021-07-20 Version: 1.0.0
- GetStack supports resource progress.
- ValidateTemplate supports Outputs.

==> alibabacloud_ros20190910_py2-2.2.3.tar.gz: alibabacloud_ros20190910_py2-2.2.3/ChangeLog.md <==
2022-04-25 Version: 2.2.2
- The Feature parameter of GetFeatureDetails is supported to be specified as TemplateScratch, which indicates the supported resource types for the template scratch.

2022-02-28 Version: 2.2.1
- The response of GetServiceProvisions adds DependentServiceNames.

2022-02-22 Version: 2.2.0
- The parameter of GetStack, GetTemplate, ListTemplates, ListTemplateVersions adds AcceptLanguage.
- The response of GetStack, GetTemplate adds Interface.
- The parameter of CreateStack, CreateChangeSet adds ServiceManaged.
- The response of GetStack adds ServiceManaged, ServiceName.
- The response of ListStacks adds ServiceManaged, ServiceName in Stacks.

2022-01-18 Version: 2.1.0
- Added EntityType to ListResourceTypes parameters.
- Added EntityType to GetResourceType return value.

2022-01-12 Version: 2.0.6
- GetFeatureDetails return value adds UpdateAllowedTransforms.

2022-01-05 Version: 2.0.5
- GetTemplate return value adds TemplateId, TemplateVersion, TemplateScratchId and TemplateURL.

2021-12-20 Version: 2.0.4
- CreateStack, PreviewStack and GetTemplateEstimateCost parameters supports specifing TemplateScratchRegionId.
- GetTemplateScratch return value adds StackProvision and UsageType in Stacks.
- GetTemplate return value adds ShareSource in Permissions.

2021-12-14 Version: 2.0.3
- Fix the issue that some parameters cannot be passed.

2021-12-07 Version: 2.0.2
- API GetStack supports Log for Terraform Stack.
- API GetChangeSet supports Log for Terraform Stack.
- API PreviewStack supports Log for Terraform Stack.

2021-11-30 Version: 2.0.1
- API GetStack supports Log for Terraform Stack.
- API GetChangeSet supports Log for Terraform Stack.
- API PreviewStack supports Log for Terraform Stack.

2021-11-22 Version: 2.0.0
- Add API GetServiceProvisions.
- Add API GetTemplateParameterConstraints.
- Add API GetFeatureDetails.
- CreateChangeSet supports Parallelism.

2021-09-27 Version: 1.1.2
- Terraform stack supports custom of parallelism.

2021-09-03 Version: 1.1.1
- Fix type error of StackGroup and StackInstance parameters.

2021-09-03 Version: 1.1.0
- StackGroup supports specify resource folder to deploy StackInstances.
- StackGroup supports SERVICE_MANAGED and SELF_MANAGED permission models.

2021-08-27 Version: 1.0.1
- Support ClientToken for ValidateTemplate.

2021-07-20 Version: 1.0.0
- GetStack supports resource progress.
- ValidateTemplate supports Outputs.
